// pageage/safetyManagement/addSafetyInspect/index.js
const app = getApp()
Page({

    /**
     * 页面的初始数据
     */
    data: {
        deptId:"",
        projectId:"",
        projectName:"",
        loginName:"",
        insuranceType:"1",
        companyName:"",
        insuranceNumber:"",
        insuranceTypeList:[],
        fileData:[],
        limit:1,
        fileType:["pdf"]
    },

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad(options) {
        let {projectId,projectName} = options
        //获取缓存数据
        wx.getStorage({
        key: 'userinfo',
        success:res=>{
            this.setData({
            projectId,
            projectName,
            deptId:res.data.deptId,
            loginName:res.data.loginName
            })
            this.getDictData(); 
        }  
        }) 
    },

    //获取字典数据
    getDictData(){
        let that = this
        wx.request({
          url: app.globalData.reqUrl+'/wechat/projectInsurance/queryInsuranceType',
          method:"get",
          data:{},
          success(res){
            res = res.data
            if(res.code == 200){
                let temData=[];
                res.data.forEach(item =>{
                    temData.push({id:item.dictValue,text:item.dictLabel});
                });
                that.setData({
                    insuranceTypeList:temData
                })
            }
          }
        })
    },

    //取消页面
    cancelSaveView(){
         /*关闭当前页面，跳转到应用内的某个页面。但是不允许跳转到 tabbar 页面*/
         wx.redirectTo({
            url: '../list/index'
        })
    },

    //保存
    onSave(){
        this.setData({
            loadShow:true
        })
        let that = this
        let {projectId,projectName,deptId,loginName,insuranceType,insuranceNumber,companyName,fileData} =  that.data;
        //数据效验
        if(projectId==""||loginName==""||deptId==""){
            app.toast("数据异常，请刷新页面重试!")
            that.setData({
                loadShow:false
            })
            return;
        }
        if(insuranceType==""){
            app.toast("请选择保险类型!")
            that.setData({
                loadShow:false
            })
            return;
        }
        if(companyName==""){
            app.toast("请填写保险公司名称!")
            that.setData({
                loadShow:false
            })
            return;
        }
        if(fileData.length==0){
            app.toast("请上传保险合同!")
            that.setData({
                loadShow:false
            });
            return;
        }
        let _fileType = fileData[0].path.split('.');
        _fileType = _fileType[_fileType.length-1].toLowerCase();
        //判断附件类型，如果是图片直接展示，非图片则显示附件
        if(this.data.fileType.indexOf(_fileType)==-1){
            app.toast("保险合同不支持 [ "+_fileType+" ] 格式!")
            that.setData({
                loadShow:false
            });
            return;
        }
        fileData.forEach(async (item)=>{
            let uploadUrl = app.globalData.uploadUrl+'/common/upload'
            let uploadName = "file" 
            //这里复杂的图片上传，改为同步上传，因为小程序只能上传一张图片
            let obj = await that.syncUploadImage(uploadUrl,fileData[0].path,uploadName);
            let params = {
                projectId,
                deptId,
                insuranceType,
                companyName,insuranceNumber,
                credentialFile:obj.data.fileName,
                createBy:loginName
            }

            wx.request({
                url: app.globalData.reqUrl + "/wechat/projectInsurance/add",
                method:"POST",
                data:params,
                header: {
                    "Username": loginName,
                    "Content-Type": "application/json"
                },
                success(res){
                    that.setData({
                        loadShow:false
                    })
                    res = res.data
                    if(res.code == 200){
                        if(res.data==-1){
                            app.toast("办理失败，当前单位已办理此类保险!")
                        }else{
                            app.toast("添加成功!")
                            setTimeout(()=>{
                            wx.redirectTo({
                                url: '../list/index',
                            })
                            },200)
                        }
                    }
                }
                })
        })
    },

    /**
     * 这里考虑上传图片异步问题，封装为同步
     */
    syncUploadImage(url,uploadFile,name) {
        return new Promise((resolve, reject) => {
            wx.uploadFile({
            url, // 上传的服务器接口地址
            filePath: uploadFile,
            header: {
                "Content-Type": "application/x-www-form-urlencoded;charset=UTF-8"      
            },
            name, //上传的所需字段，后端提供
            formData: { user: 'test' },
            success: (res) => {
                // 上传完成操作
                const data = JSON.parse(res.data)
                resolve({
                    data: data
                })
            },
            fail: (err) => {
                //上传失败：修改pedding为reject
                console.log("访问接口失败", err);
                wx.showToast({
                title: "网络出错,上传失败",
                icon: 'none',
                duration: 1000
                });
                reject(err)
            }
            });
        })
    },

    companyNameAction: function (options) {
        this.data.companyName = options.detail.value;
    },

    insuranceNumberAction: function (options) {
        this.data.insuranceNumber = options.detail.value
    },

    fileUpload(options){
        let file=options.detail;
        this.setData({
            fileData: file
        });
    },

    returnToPage: function () {
        /*关闭当前页面，跳转到应用内的某个页面。但是不允许跳转到 tabbar 页面*/
        wx.redirectTo({
            url: '../list/index',
        })
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady() {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow() {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide() {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload() {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh() {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom() {

    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage() {

    }
})